@@ -209,3 +209,11 @@ def test_relative_static_url(server, static_files, _collect_static):
         url = storage.staticfiles_storage.url(static_files.js_path)
         response = server.get(url)
         assert response.content == static_files.js_content
+
+
+@override_settings(FORCE_SCRIPT_NAME="/subdir", STATIC_URL="static/")
+def test_force_script_name(server, static_files, _collect_static):
+    url = storage.staticfiles_storage.url(static_files.js_path)
+    assert url.startswith("/subdir/static/")
+    response = server.get(url)
+    assert response.content == static_files.js_content
